Público em Geral / Nota Fiscal Eletrônica / Consulta Completa da NFC-e

CONSULTA DA NFC-e
| ELISA BERTRAM E CIA LTDA
CNPJ: 02.589.899/0001-55 Inscrição Estadual: 1080119148
ESTRADA RST 287, KM 92, S/N, PINHEIRAL, Santa Cruz do Sul, RS
DANFE NFC-e - Documento Auxiliar da Nota Fiscal Eletrônica para Consumidor Final - Via Consumidor
NFC-e não permite aproveitamento de crédito de ICMS
Emissão normal
NFC-e nº: 94091 Série: 2 Data de Emissão: 28/09/2019 17:25:07
Consulte pela Chave de Acesso em https://www.sefaz.rs.gov.br/NFCE
CHAVE DE ACESSO
4319 0902 5898 9900 0155 6500 2000 0940 9114 6694 6901
Protocolo de Autorização: 143191331479554
CONSUMIDOR
CPF: 044.272.479-97
Código | Descrição | Qtde | Un | Vl Unit | Vl Total
866 | CUCA DE REQUEIJAO | 0,608 | KG | 25,5 | 15,50
1005 | CUCA MORANGO COM CHOCOLATE | 0,656 | KG | 25,5 | 16,72
Valor total R$ | 32,22
Valor descontos R$ | 0,00
FORMA PAGAMENTO | VALOR PAGO R$
| NaN
Versão XSLT: 1.10

Administração Tributária: | Receita Estadual RS
Data/Hora da Consulta: | 11/08/2020 12:32:28